@@ -1,16 +1,21 @@
 from __future__ import annotations
 
-from PySide2.QtCore import Qt
-from PySide2.QtGui import (QKeyEvent, QKeySequence, QRegExpValidator,
+from enum import IntEnum
+
+from PySide6.QtCore import Qt
+from PySide6.QtGui import (QKeyEvent, QKeySequence, QRegularExpressionValidator,
                            QTextOption)
-from PySide2.QtWidgets import QApplication, QPlainTextEdit, QTreeWidgetItem
+from PySide6.QtWidgets import QApplication, QPlainTextEdit, QTreeWidgetItem
 
 from ..fst import FSTNode
 
+# pylint: disable=invalid-name
+# pylint: disable=no-member
+
 
 class FilteredPlainTextEdit(QPlainTextEdit):
 
-    class ScrollPolicy:
+    class ScrollPolicy(IntEnum):
         NoScroll = 0
         ScrollVertical = 1
         ScrollHorizontal = 2
@@ -40,7 +45,7 @@ class FilteredPlainTextEdit(QPlainTextEdit):
     def setMaxLength(self, length: int):
         self._maxlength = length
 
-    def setValidator(self, validator: QRegExpValidator):
+    def setValidator(self, validator: QRegularExpressionValidator):
         self._validator = validator
 
     def keyPressEvent(self, e: QKeyEvent):
@@ -132,7 +137,7 @@ class FSTTreeItem(QTreeWidgetItem):
 
     @property
     def position(self) -> int:
-        self.node._fileoffset
+        return self.node._fileoffset
 
     @position.setter
     def position(self, pos: int):
@@ -147,11 +152,14 @@ class FSTTreeItem(QTreeWidgetItem):
         self.node._exclude = exclude
 
     def __lt__(self, other: FSTTreeItem):
+        """ Used for tree sorting """
         if self.node.is_root() and not other.node.is_root():
             return True
-        elif self.node.is_dir() and other.node.is_file():
+        if self.node.is_dir() and other.node.is_file():
             return True
-        elif self.node.is_file() and other.node.is_dir():
+        if self.node.is_file() and other.node.is_dir():
             return False
-        else:
-            return self.node._id < other.node._id
+        return self.node._id < other.node._id
+
+# pylint: enable=invalid-name
+# pylint: enable=no-member
