@@ -1,11 +1,10 @@
 from __future__ import annotations
 
 import json
-from datetime import datetime
 from fnmatch import fnmatch
 from io import BytesIO
 from pathlib import Path
-from typing import Optional, Union
+from typing import BinaryIO, Callable, Optional, Union
 
 from dolreader.dol import DolFile
 from sortedcontainers import SortedDict, SortedList
@@ -20,27 +19,16 @@ from pyisotools.iohelper import (align_int, read_string, read_ubyte,
 
 
 class FileSystemTooLargeError(Exception):
-    pass
+    ...
+
 
 class FileSystemInvalidError(Exception):
-    pass
-
-class _Progress(object):
-    def __init__(self):
-        self.jobProgress = 0
-        self.jobSize = 0
-        self._isReady = False
-
-    def set_ready(self, ready: bool):
-        self._isReady = ready
-
-    def is_ready(self) -> bool:
-        return self._isReady
+    ...
 
 
 class _ISOInfo(FST):
 
-    def __init__(self, iso: Path = None):
+    def __init__(self):
         super().__init__()
         self.root: Path = None
 
@@ -49,12 +37,23 @@ class _ISOInfo(FST):
         self._dataOfs = 0
         self._prevfile = None
 
+# pylint: disable=not-callable
+
 
 class ISOBase(_ISOInfo):
 
     def __init__(self):
         super().__init__()
-        self.progress = _Progress()
+
+        # File extraction callbacks
+        self._onPhysicalJobStart: Callable[[int], None] = None
+        self._onPhysicalJobComplete: Callable[[int], None] = None
+        self._onPhysicalJobExit: Callable[[int], None] = None
+
+        # ISO build callbacks
+        self._onVirtualJobStart: Callable[[int], None] = None
+        self._onVirtualJobComplete: Callable[[int], None] = None
+        self._onVirtualJobExit: Callable[[int], None] = None
 
         self.isoPath = None
         self.bootheader = None
@@ -67,6 +66,72 @@ class ISOBase(_ISOInfo):
         self._locationTable = SortedDict()
         self._excludeTable = SortedList()
 
+    # pylint: disable=unused-argument
+    @staticmethod
+    def __default_callback(*args, **kwargs) -> None:
+        return None
+    # pylint: enable=unused-argument
+
+    @property
+    def onPhysicalJobStart(self) -> Callable[[int], None]:
+        if self._onPhysicalJobStart:
+            return self._onPhysicalJobStart
+        return self.__default_callback
+
+    @onPhysicalJobStart.setter
+    def onPhysicalJobStart(self, callback: Callable[[int], None]):
+        self._onPhysicalJobStart = callback
+
+    @property
+    def onPhysicalJobComplete(self) -> Callable[[int], None]:
+        if self._onPhysicalJobComplete:
+            return self._onPhysicalJobComplete
+        return self.__default_callback
+
+    @onPhysicalJobComplete.setter
+    def onPhysicalJobComplete(self, callback: Callable[[int], None]):
+        self._onPhysicalJobComplete = callback
+
+    @property
+    def onPhysicalJobExit(self) -> Callable[[int], None]:
+        if self._onPhysicalJobExit:
+            return self._onPhysicalJobExit
+        return self.__default_callback
+
+    @onPhysicalJobExit.setter
+    def onPhysicalJobExit(self, callback: Callable[[int], None]):
+        self._onPhysicalJobExit = callback
+
+    @property
+    def onVirtualJobStart(self) -> Callable[[int], None]:
+        if self._onVirtualJobStart:
+            return self._onVirtualJobStart
+        return self.__default_callback
+
+    @onVirtualJobStart.setter
+    def onVirtualJobStart(self, callback: Callable[[int], None]):
+        self._onVirtualJobStart = callback
+
+    @property
+    def onVirtualJobComplete(self) -> Callable[[int], None]:
+        if self._onVirtualJobComplete:
+            return self._onVirtualJobComplete
+        return self.__default_callback
+
+    @onVirtualJobComplete.setter
+    def onVirtualJobComplete(self, callback: Callable[[int], None]):
+        self._onVirtualJobComplete = callback
+
+    @property
+    def onVirtualJobExit(self) -> Callable[[int], None]:
+        if self._onVirtualJobExit:
+            return self._onVirtualJobExit
+        return self.__default_callback
+
+    @onVirtualJobExit.setter
+    def onVirtualJobExit(self, callback: Callable[[int], None]):
+        self._onVirtualJobExit = callback
+
     def _read_nodes(self, fst, node: FSTNode, strTabOfs: int) -> FSTNode:
         _type = read_ubyte(fst)
         _nameOfs = int.from_bytes(fst.read(3), "big", signed=False)
@@ -74,7 +139,7 @@ class ISOBase(_ISOInfo):
         _size = read_uint32(fst)
 
         _oldpos = fst.tell()
-        node.name = read_string(fst, strTabOfs + _nameOfs, encoding="shift-jis")
+        node.name = read_string(fst, strTabOfs + _nameOfs)
         fst.seek(_oldpos)
 
         node._id = self._curEntry
@@ -112,19 +177,18 @@ class ISOBase(_ISOInfo):
             self._locationTable = SortedDict(data["location"])
             self._excludeTable = SortedList(data["exclude"])
 
-    def _recursive_extract(self, path: Path, dest: Path, iso):
-        node = self.find_by_path(path)
-        if not node:
-            return
-
+    def _recursive_extract(self, node: FSTNode, dest: Path, iso: BinaryIO, dumpPositions: bool = False):
         if node.is_file():
             iso.seek(node._fileoffset)
             dest.write_bytes(iso.read(node.size))
-            self.progress.jobProgress += node.size
+            self.onPhysicalJobComplete(node.size)
         else:
             dest.mkdir(parents=True, exist_ok=True)
             for child in node.children:
-                self._recursive_extract(path/child.name, dest/child.name, iso)
+                self._recursive_extract(child, dest/child.name, iso)
+
+        if dumpPositions:
+            self._locationTable[node.path] = node._fileoffset
 
     def _collect_size(self, size: int) -> int:
         for node in self.children:
@@ -152,11 +216,16 @@ class ISOBase(_ISOInfo):
         else:
             _path = node
 
-        if self._alignmentTable:
-            for entry, align in self._alignmentTable.items():
-                if fnmatch(_path, entry.strip()):
-                    return align
-        return 4
+        alignment = 4
+        if self._alignmentTable is None:
+            return alignment
+
+        for entry, width in self._alignmentTable.items():
+            if fnmatch(_path, entry.strip()):
+                alignment = width
+                break
+
+        return alignment
 
     def _get_location(self, node: Union[FSTNode, str]) -> int:
         if isinstance(node, FSTNode):
@@ -166,6 +235,7 @@ class ISOBase(_ISOInfo):
 
         if self._locationTable:
             return self._locationTable.get(_path)
+        return None
 
     def _get_excluded(self, node: Union[FSTNode, str]) -> bool:
         if isinstance(node, FSTNode):
@@ -184,9 +254,6 @@ class WiiISO(ISOBase):
 
     MaxSize = 4699979776
 
-    def __init__(self):
-        super().__init__()
-
 
 class GamecubeISO(ISOBase):
 
@@ -212,16 +279,14 @@ class GamecubeISO(ISOBase):
     def configPath(self) -> Path:
         if self.root:
             return self.systemPath / ".config.json"
-        else:
-            return None
+        return None
 
     @property
     def systemPath(self) -> Path:
         if self.root:
             if self.is_gcr_root():
                 return self.root / "&&systemdata"
-            else:
-                return self.root / "sys"
+            return self.root / "sys"
         return None
 
     @property
@@ -229,8 +294,7 @@ class GamecubeISO(ISOBase):
         if self.root:
             if self.is_gcr_root():
                 return self.root
-            else:
-                return self.root / self.name
+            return self.root / self.name
         return None
 
     @staticmethod
@@ -243,25 +307,22 @@ class GamecubeISO(ISOBase):
         virtualISO = GamecubeISO.from_iso(iso)
         virtualISO.extract(dest)
 
-    def is_dolphin_root(self) -> Path:
+    def is_dolphin_root(self) -> bool:
         if self.root:
-            folders = [x.name.lower() for x in self.root.iterdir() if x.is_dir()]
+            folders = {x.name.lower()
+                       for x in self.root.iterdir() if x.is_dir()}
             return "sys" in folders and "files" in folders and "&&systemdata" not in folders
-        else:
-            return False
+        return False
 
-    def is_gcr_root(self) -> Path:
+    def is_gcr_root(self) -> bool:
         if self.root:
-            folders = [x.name.lower() for x in self.root.iterdir() if x.is_dir()]
+            folders = {x.name.lower()
+                       for x in self.root.iterdir() if x.is_dir()}
             return "&&systemdata" in folders
-        else:
-            return False
+        return False
 
     def build(self, dest: Union[Path, str] = None, preCalc: bool = True):
-        self.progress.set_ready(False)
-        self.progress.jobProgress = 0
-        self.progress.jobSize = self.MaxSize
-        self.progress.set_ready(True)
+        self.onVirtualJobStart(self.MaxSize)
 
         if dest is not None:
             fmtpath = str(dest).replace(
@@ -277,7 +338,8 @@ class GamecubeISO(ISOBase):
         # --- FST --- #
 
         if preCalc:
-            self.pre_calc_metadata((self.MaxSize - self.get_auto_blob_size()) & -self._get_greatest_alignment())
+            self.pre_calc_metadata(
+                (self.MaxSize - self.get_auto_blob_size()) & -self._get_greatest_alignment())
 
         self._rawFST.seek(0)
         self._rawFST.write(b"\x01\x00\x00\x00\x00\x00\x00\x00")
@@ -290,14 +352,15 @@ class GamecubeISO(ISOBase):
             child._id = _curEntry
             self._rawFST.write(b"\x01" if child.is_dir() else b"\x00")
             self._rawFST.write((_strOfs).to_bytes(3, "big", signed=False))
-            write_uint32(self._rawFST, child.parent._id if child.is_dir() else child._fileoffset)
+            write_uint32(
+                self._rawFST, child.parent._id if child.is_dir() else child._fileoffset)
             write_uint32(self._rawFST, len(child) +
-                        _curEntry if child.is_dir() else child.size)
+                         _curEntry if child.is_dir() else child.size)
             _curEntry += 1
 
             _oldpos = self._rawFST.tell()
             self._rawFST.seek(_strOfs + _strTableOfs)
-            self._rawFST.write(child.name.encode("shift-jis") + b"\x00")
+            self._rawFST.write(child.name.encode() + b"\x00")
             _strOfs += len(child.name) + 1
             self._rawFST.seek(_oldpos)
 
@@ -328,7 +391,7 @@ class GamecubeISO(ISOBase):
             with Path(self.systemPath, "AppLoader.ldr").open("wb") as f:
                 self.apploader.save(f)
 
-            with Path(self.systemPath, "Game.toc").open("wb") as f: 
+            with Path(self.systemPath, "Game.toc").open("wb") as f:
                 f.write(self._rawFST.getvalue())
         else:
             raise InvalidFSTError(f"{self.root} is not a valid root folder")
@@ -337,50 +400,49 @@ class GamecubeISO(ISOBase):
 
         # -- Files -- #
 
+        self.bnr.save_bnr(Path(self.dataPath, "opening.bnr"))
+
         with self.isoPath.open("wb") as f:
             self.bootheader.save(f)
-            self.progress.jobProgress += 0x440
+            self.onVirtualJobComplete(0x440)
 
             self.bootinfo.save(f)
-            self.progress.jobProgress += 0x2000
+            self.onVirtualJobComplete(0x2000)
 
             self.apploader.save(f)
-            self.progress.jobProgress += self.apploader.loaderSize + self.apploader.trailerSize
+            self.onVirtualJobComplete(
+                self.apploader.loaderSize + self.apploader.trailerSize)
 
             f.write(b"\x00" * (self.bootheader.dolOffset - f.tell()))
             self.dol.save(f, self.bootheader.dolOffset)
-            self.progress.jobProgress += self.dol.size
+            self.onVirtualJobComplete(self.dol.size)
 
             f.seek(f.tell() + self.dol.size)
             f.write(b"\x00" * (self.bootheader.fstOffset - f.tell()))
 
             f.write(self._rawFST.getvalue())
-            self.progress.jobProgress += len(self._rawFST.getbuffer())
-            
+            self.onVirtualJobComplete(len(self._rawFST.getbuffer()))
+
             for child in self.rfiles(includedOnly=True):
                 f.write(b"\x00" * (child._fileoffset - f.tell()))
                 f.seek(child._fileoffset)
                 f.write((self.dataPath / child.path).read_bytes())
                 f.seek(0, 2)
-                self.progress.jobProgress += child.size
+                self.onVirtualJobComplete(child.size)
 
             f.write(b"\x00" * (self.MaxSize - f.tell()))
 
         # ----------- #
-        
-        self.progress.jobProgress = self.MaxSize
+
+        self.onVirtualJobExit(self.MaxSize)
 
     def extract(self, dest: Union[Path, str] = None, dumpPositions: bool = True):
-        self.progress.set_ready(False)
-        self.progress.jobProgress = 0
-
         jobSize = self.size + \
             (0x2440 + (self.apploader.loaderSize + self.apploader.trailerSize))
         jobSize += self.dol.size
         jobSize += len(self._rawFST.getbuffer())
 
-        self.progress.jobSize = jobSize
-        self.progress.set_ready(True)
+        self.onPhysicalJobStart(jobSize)
 
         if dest is not None:
             self.root = Path(f"{dest}/root")
@@ -392,56 +454,42 @@ class GamecubeISO(ISOBase):
         with Path(systemPath, "boot.bin").open("wb") as f:
             self.bootheader.save(f)
 
-        self.progress.jobProgress += 0x440
+        self.onPhysicalJobComplete(0x440)
 
         with Path(systemPath, "bi2.bin").open("wb") as f:
             self.bootinfo.save(f)
 
-        self.progress.jobProgress += 0x2000
+        self.onPhysicalJobComplete(0x2000)
 
         with Path(systemPath, "apploader.img").open("wb") as f:
             self.apploader.save(f)
 
-        self.progress.jobProgress += self.apploader.loaderSize + self.apploader.trailerSize
+        self.onPhysicalJobComplete(
+            self.apploader.loaderSize + self.apploader.trailerSize)
 
         with Path(systemPath, "main.dol").open("wb") as f:
             self.dol.save(f)
 
-        self.progress.jobProgress += self.dol.size
+        self.onPhysicalJobComplete(self.dol.size)
 
         with Path(systemPath, "fst.bin").open("wb") as f:
             f.write(self._rawFST.getvalue())
 
-        self.progress.jobProgress += len(self._rawFST.getbuffer())
+        self.onPhysicalJobComplete(len(self._rawFST.getbuffer()))
 
         self.dataPath.mkdir(parents=True, exist_ok=True)
-        with self.isoPath.open("rb") as _iso:
-            for child in self.rchildren():
-                _dest = self.dataPath / child.path
-                if child.is_file():
-                    with _dest.open("wb") as f:
-                        _iso.seek(child._fileoffset)
-                        f.write(_iso.read(child.size))
-                        self.progress.jobProgress += child.size
-                    if dumpPositions:
-                        self._locationTable[child.path] = child._fileoffset
-                else:
-                    _dest.mkdir(exist_ok=True)
+        self.extract_path("", self.dataPath.parent, dumpPositions)
 
         self.save_config()
-        self.progress.jobProgress = self.progress.jobSize
+        self.onPhysicalJobExit(jobSize)
 
     def extract_system_data(self, dest: Union[Path, str] = None):
-        self.progress.set_ready(False)
-        self.progress.jobProgress = 0
-
         jobSize = 0x2440 + (self.apploader.loaderSize +
                             self.apploader.trailerSize)
         jobSize += self.dol.size
         jobSize += len(self._rawFST.getbuffer())
 
-        self.progress.jobSize = jobSize
-        self.progress.set_ready(True)
+        self.onPhysicalJobStart(jobSize)
 
         systemPath = dest / "sys"
         systemPath.mkdir(parents=True, exist_ok=True)
@@ -449,38 +497,36 @@ class GamecubeISO(ISOBase):
         with Path(systemPath, "boot.bin").open("wb") as f:
             self.bootheader.save(f)
 
-        self.progress.jobProgress += 0x440
+        self.onPhysicalJobComplete(0x440)
 
         with Path(systemPath, "bi2.bin").open("wb") as f:
             self.bootinfo.save(f)
 
-        self.progress.jobProgress += 0x2000
+        self.onPhysicalJobComplete(0x2000)
 
         with Path(systemPath, "apploader.img").open("wb") as f:
             self.apploader.save(f)
 
-        self.progress.jobProgress += self.apploader.loaderSize + self.apploader.trailerSize
+        self.onPhysicalJobComplete(
+            self.apploader.loaderSize + self.apploader.trailerSize)
 
         with Path(systemPath, "main.dol").open("wb") as f:
             self.dol.save(f)
 
-        self.progress.jobProgress += self.dol.size
+        self.onPhysicalJobComplete(self.dol.size)
 
         with Path(systemPath, "fst.bin").open("wb") as f:
             f.write(self._rawFST.getvalue())
 
-        self.progress.jobProgress += len(self._rawFST.getbuffer())
+        self.onPhysicalJobExit(len(self._rawFST.getbuffer()))
 
     def save_system_data(self):
-        self.progress.set_ready(False)
-        self.progress.jobProgress = 0
-
-        jobSize = 0x2440 + (self.apploader.loaderSize + self.apploader.trailerSize)
+        jobSize = 0x2440 + (self.apploader.loaderSize +
+                            self.apploader.trailerSize)
         jobSize += self.dol.size
         jobSize += self.num_children()
 
-        self.progress.jobSize = jobSize
-        self.progress.set_ready(True)
+        self.onPhysicalJobStart(jobSize)
 
         systemPath = self.systemPath
 
@@ -488,17 +534,18 @@ class GamecubeISO(ISOBase):
             with Path(systemPath, "boot.bin").open("wb") as f:
                 self.bootheader.save(f)
 
-            self.progress.jobProgress += 0x440
+            self.onPhysicalJobComplete(0x440)
 
             with Path(systemPath, "bi2.bin").open("wb") as f:
                 self.bootinfo.save(f)
 
-            self.progress.jobProgress += 0x2000
+            self.onPhysicalJobComplete(0x2000)
 
             with Path(systemPath, "apploader.img").open("wb") as f:
                 self.apploader.save(f)
 
-            self.progress.jobProgress += self.apploader.loaderSize + self.apploader.trailerSize
+            self.onPhysicalJobComplete(
+                self.apploader.loaderSize + self.apploader.trailerSize)
 
             with Path(systemPath, "main.dol").open("wb") as f:
                 self.dol.save(f)
@@ -507,64 +554,66 @@ class GamecubeISO(ISOBase):
                 self.bootheader.save(f)
                 self.bootinfo.save(f)
 
-            self.progress.jobProgress += 0x2440
+            self.onPhysicalJobComplete(0x2440)
 
             with Path(systemPath, "Apploader.ldr").open("wb") as f:
                 self.apploader.save(f)
 
-            self.progress.jobProgress += self.apploader.loaderSize + self.apploader.trailerSize
+            self.onPhysicalJobComplete(
+                self.apploader.loaderSize + self.apploader.trailerSize)
 
             with Path(systemPath, "Start.dol").open("wb") as f:
                 self.dol.save(f)
         else:
             raise InvalidFSTError(f"{self.root} is not a valid root folder")
 
-        self.progress.jobProgress += self.dol.size
+        if self.bnr:
+            self.bnr.save_bnr(Path(self.dataPath, "opening.bnr"))
+
+        self.onPhysicalJobComplete(self.dol.size)
         self._save_config_regen()
-        self.progress.jobProgress = self.progress.jobSize
+        self.onPhysicalJobExit(jobSize)
 
     def save_system_datav(self):
-        self.progress.set_ready(False)
-        self.progress.jobProgress = 0
-
-        jobSize = 0x2440 + (self.apploader.loaderSize + self.apploader.trailerSize)
+        jobSize = 0x2440 + (self.apploader.loaderSize +
+                            self.apploader.trailerSize)
         jobSize += self.dol.size
 
-        self.progress.jobSize = jobSize
-        self.progress.set_ready(True)
-        
+        self.onVirtualJobStart(jobSize)
+
         with self.isoPath.open("r+b") as f:
             self.bootheader.save(f)
-            self.progress.jobProgress += 0x440
-
+            self.onVirtualJobComplete(0x440)
             self.bootinfo.save(f)
-            self.progress.jobProgress += 0x2000
-
+            self.onVirtualJobComplete(0x2000)
             self.apploader.save(f)
-
-            f.write(b"\x00" * (self.bootheader.dolOffset - f.tell()))
+            self.onVirtualJobComplete(
+                self.apploader.loaderSize + self.apploader.trailerSize)
             self.dol.save(f, self.bootheader.dolOffset)
+            self.onVirtualJobComplete(self.dol.size)
 
-            self.progress.jobProgress += self.dol.size
+            bnrNode = self.find_by_path("opening.bnr")
+            if bnrNode:
+                f.seek(bnrNode._fileoffset)
+                f.write(self.bnr._rawdata.getvalue())
+
+        self.onVirtualJobExit(jobSize)
 
     def get_auto_blob_size(self) -> int:
-        def _collect_size(node: FSTNode, _size: int):
-            for child in node.children:
-                if child._exclude or child._position:
-                    continue
-                
-                if child.is_file():
-                    _size = align_int(_size, child._alignment) + child.size
-                else:
-                    _size = _collect_size(child, _size)
+        _size = 0
 
-            return _size
+        for child in self.rfiles(includedOnly=True):
+            if child._position:
+                continue
 
-        return _collect_size(self, 0)
+            _size = align_int(_size, child._alignment) + child.size
+
+        return _size
 
     def init_from_iso(self, iso: Path):
         self.isoPath = iso
         self.root = Path(iso.parent, "root").resolve()
+
         with iso.open("rb") as _rawISO:
             self.bootheader = Boot(_rawISO)
             self.bootinfo = BI2(_rawISO)
@@ -589,11 +638,13 @@ class GamecubeISO(ISOBase):
         if bnrNode:
             with iso.open("rb") as _rawISO:
                 _rawISO.seek(bnrNode._fileoffset)
-                self.bnr = BNR.from_data(_rawISO, region=region, size=bnrNode.size)
+                self.bnr = BNR.from_data(
+                    _rawISO, region=region, size=bnrNode.size)
         else:
             self.bnr = None
 
-        prev = FSTNode.file("", None, self.bootheader.fstSize, self.bootheader.fstOffset)
+        prev = FSTNode.file("", None, self.bootheader.fstSize,
+                            self.bootheader.fstOffset)
         for node in self.nodes_by_offset():
             alignment = self._detect_alignment(node, prev)
             if alignment != 4:
@@ -663,22 +714,25 @@ class GamecubeISO(ISOBase):
         self.isoPath = Path(
             root.parent / f"{self.bootheader.gameName} [{self.bootheader.gameCode}{self.bootheader.makerCode}].iso").resolve()
 
-    def extract_path(self, path: Path, dest: Path):
-        self.progress.set_ready(False)
+    def extract_path(self, path: Union[Path, str], dest: Union[Path, str], dumpPositions: bool = False):
+        if isinstance(path, str):
+            path = Path(path)
+
+        if isinstance(dest, str):
+            dest = Path(dest)
 
         node = self.find_by_path(path)
-
         if not node:
             return
 
-        self.progress.jobProgress = 0
-        self.progress.jobSize = node.datasize
-        self.progress.set_ready(True)
+        jobSize = node.datasize
+        self.onPhysicalJobStart(jobSize)
 
         with self.isoPath.open("rb") as _rawISO:
-            self._recursive_extract(path, dest / node.name, _rawISO)
+            self._recursive_extract(
+                node, dest / node.name, _rawISO, dumpPositions)
 
-        self.progress.jobProgress = self.progress.jobSize
+        self.onPhysicalJobExit(jobSize)
 
     def replace_path(self, path: str, new: Path):
         """
@@ -710,7 +764,8 @@ class GamecubeISO(ISOBase):
         _minOffset = self.MaxSize - 4
         for child in self.rchildren():
             if child.is_file() and child._position:
-                child._fileoffset = align_int(child._position, child._alignment)
+                child._fileoffset = align_int(
+                    child._position, child._alignment)
                 if child._fileoffset < _minOffset:
                     _minOffset = child._fileoffset
 
@@ -736,7 +791,7 @@ class GamecubeISO(ISOBase):
 
         self.bootheader.firstFileOffset = max(_minOffset, 0)
 
-    def load_file_system(self, path: Path, parentnode: FSTNode = None, ignoreList=[]):
+    def load_file_system(self, path: Path, parentnode: FSTNode = None, ignoreList=None):
         """
         Converts a directory into an FST and loads into self for further use
 
@@ -744,6 +799,8 @@ class GamecubeISO(ISOBase):
             parentnode: Parent to store all info under
             ignorelist: List of filepaths to ignore as glob patterns
         """
+        if ignoreList is None:
+            ignoreList = []
 
         self._init_tables(self.configPath)
 
@@ -751,9 +808,10 @@ class GamecubeISO(ISOBase):
             ignoreList.extend(self._excludeTable)
 
         self._load_from_path(path, parentnode, ignoreList)
-        self.pre_calc_metadata(self.MaxSize - self.get_auto_blob_size())
+        self.pre_calc_metadata(
+            (self.MaxSize - self.get_auto_blob_size()) & -self._get_greatest_alignment())
 
-    def load_file_systemv(self, fst):
+    def load_file_systemv(self, fst: BinaryIO):
         """
         Loads the file system data from a memory buffer into self for further use
 
@@ -762,9 +820,9 @@ class GamecubeISO(ISOBase):
 
         if fst.read(1) != b"\x01":
             raise InvalidFSTError("Invalid Root flag found")
-        elif fst.read(3) != b"\x00\x00\x00":
+        if fst.read(3) != b"\x00\x00\x00":
             raise InvalidFSTError("Invalid Root string offset found")
-        elif fst.read(4) != b"\x00\x00\x00\x00":
+        if fst.read(4) != b"\x00\x00\x00\x00":
             raise InvalidFSTError("Invalid Root offset found")
 
         self._alignmentTable = SortedDict()
@@ -776,12 +834,15 @@ class GamecubeISO(ISOBase):
             self.add_child(child)
 
     def load_config(self, path: Path):
+        if not path.is_file():
+            return
+
         with path.open("r") as f:
             data = json.load(f)
 
         self._init_tables(data)
 
-        if "name" in data: #convert legacy to new
+        if "name" in data:  # convert legacy to new
             self.bootheader.gameName = data["name"]
             self.bootheader.gameCode = data["gameid"][:4]
             self.bootheader.makerCode = data["gameid"][4:6]
@@ -804,8 +865,8 @@ class GamecubeISO(ISOBase):
                       "devtitle": self.bnr.developerTitle if self.bnr else "",
                       "description": self.bnr.gameDescription if self.bnr else "",
                       "alignment": self._alignmentTable,
-                      "location": {k : self._locationTable[k] for k in sorted(self._locationTable, key=str.upper)},
-                      "exclude": [x for x in self._excludeTable]}
+                      "location": {k: self._locationTable[k] for k in sorted(self._locationTable, key=str.upper)},
+                      "exclude": list(self._excludeTable)}
             with path.open("w") as f:
                 json.dump(config, f, indent=4)
         else:
@@ -833,8 +894,8 @@ class GamecubeISO(ISOBase):
                   "devtitle": self.bnr.developerTitle if self.bnr else "",
                   "description": self.bnr.gameDescription if self.bnr else "",
                   "alignment": self._alignmentTable,
-                  "location": {k : self._locationTable[k] for k in sorted(self._locationTable, key=str.upper)},
-                  "exclude": [x for x in self._excludeTable]}
+                  "location": {k: self._locationTable[k] for k in sorted(self._locationTable, key=str.upper)},
+                  "exclude": list(self._excludeTable)}
 
         with self.configPath.open("w") as f:
             json.dump(config, f, indent=4)
@@ -845,12 +906,13 @@ class GamecubeISO(ISOBase):
                 continue
 
             disable = False
-            for p in ignoreList:
-                if entry.match(p):
+            for badPath in ignoreList:
+                if entry.match(badPath):
                     disable = True
 
             if entry.is_file():
-                child = FSTNode.file(entry.name, parent=parentnode, size=entry.stat().st_size)
+                child = FSTNode.file(
+                    entry.name, parent=parentnode, size=entry.stat().st_size)
                 child._alignment = self._get_alignment(child)
                 child._position = self._get_location(child)
                 child._exclude = disable
@@ -881,3 +943,5 @@ class GamecubeISO(ISOBase):
                 self._excludeTable.add(node.path)
 
         self.save_config()
+
+# pylint: enable=not-callable
